@@ -18,3 +18,10 @@ test_that("empty expansion returns original", {
   rs <- complete.(df, y = NULL)
   expect_equal(rs, df)
 })
+
+test_that("not drop unspecified levels in complete", {
+  df <- tidytable(x = 1:3, y = 1:3, z = c("a", "b", "c"))
+  df2 <- df %>% complete.(z = c("a", "b"))
+  expect <- df[, c("z", "x", "y")]
+  expect_equal(df2, expect)
+})
